@@ -7,6 +7,5 @@ from .user import User
 from .user_verification import UserVerification
 
 
-_ = None
-del _
+''''''
 from .helpers import BotHelper, RedditAppHelper, UserHelper, UserVerificationHelper, SentryTokenHelper, DatabaseCredentialHelper, RefreshTokenHelper
\ No newline at end of file
