@@ -106,9 +106,9 @@ class RedditApp(BaseApp):
         :param bool permanent: Determines if a refresh token will be provided. (default: ``False``)
         :param Union[UserVerification,int,str] userVerification: Link to a :class:`.UserVerification` object. Accepted values are:
 
-            - An :class:``.UserVerification`` object
-            - An :class:``.UserVerification`` id
-            - An ``userId`` of a :class:``.UserVerification`` record.
+            - An :class:`.UserVerification` object
+            - An :class:`.UserVerification` ``id``
+            - An ``userId`` of a :class:`.UserVerification` record.
 
          If a :class:`.UserVerification` record does not exist, one will be created.
         :return str: Auth URL
@@ -131,4 +131,4 @@ class RedditApp(BaseApp):
             state = base64.urlsafe_b64encode(f'{self.state}:{uVerification}'.encode()).decode()
         else:
             state = self.state
-        return self.reddit().auth.url(scopes, state, duration)
\ No newline at end of file
+        return self.reddit().auth.url(scopes, state, duration)
